rayoptics.parax package
=======================

.. automodule:: rayoptics.parax
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

rayoptics.parax.diagram module
------------------------------

.. automodule:: rayoptics.parax.diagram
   :members:
   :undoc-members:
   :show-inheritance:

rayoptics.parax.etendue module
------------------------------

.. automodule:: rayoptics.parax.etendue
   :members:
   :undoc-members:
   :show-inheritance:

rayoptics.parax.firstorder module
---------------------------------

.. automodule:: rayoptics.parax.firstorder
   :members:
   :undoc-members:
   :show-inheritance:

rayoptics.parax.idealimager module
----------------------------------

.. automodule:: rayoptics.parax.idealimager
   :members:
   :undoc-members:
   :show-inheritance:

rayoptics.parax.paraxialdesign module
-------------------------------------

.. automodule:: rayoptics.parax.paraxialdesign
   :members:
   :undoc-members:
   :show-inheritance:

rayoptics.parax.specsheet module
--------------------------------

.. automodule:: rayoptics.parax.specsheet
   :members:
   :undoc-members:
   :show-inheritance:

rayoptics.parax.thirdorder module
---------------------------------

.. automodule:: rayoptics.parax.thirdorder
   :members:
   :undoc-members:
   :show-inheritance:

